@@ -1,12 +1,11 @@
 ;;; org-modern.el --- Modern looks for Org -*- lexical-binding: t -*-
 
-;; Copyright (C) 2022-2025 Free Software Foundation, Inc.
+;; Copyright (C) 2022-2026 Free Software Foundation, Inc.
 
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2022
-;; Package-Version: 1.11
-;; Package-Revision: 55b5bbeb1eb9
+;; Version: 1.11
 ;; Package-Requires: ((emacs "29.1") (org "9.6") (compat "30"))
 ;; URL: https://github.com/minad/org-modern
 ;; Keywords: outlines, hypermedia, text
@@ -48,11 +47,11 @@
   :group 'org
   :prefix "org-modern-")
 
-(defcustom org-modern-label-border 'auto
+(defcustom org-modern-label-border 0.1
   "Line width used for tag label borders.
-If set to `auto' the border width is computed based on the `line-spacing'.
-A value between 0.1 and 0.4 of `line-spacing' is recommended."
-  :type '(choice (const nil) (const auto) integer))
+Integers are interpreted as pixels and floats as fraction of the
+character height."
+  :type '(choice (const nil) function number))
 
 (defcustom org-modern-star 'fold
   "Style heading stars.
@@ -408,15 +407,15 @@ the font.")
   (let* ((beg (match-beginning 1))
          (end (match-end 1))
          (prio (char-before (1- end))))
-    (if-let ((rep (and (consp org-modern-priority)
-                       (cdr (assq prio org-modern-priority)))))
+    (if-let* ((rep (and (consp org-modern-priority)
+                        (cdr (assq prio org-modern-priority)))))
         (put-text-property beg end 'display rep)
       (put-text-property beg (1+ beg) 'display " ")
       (put-text-property (1- end) end 'display " ")
       (put-text-property
        beg end 'face
-       (if-let ((face (or (cdr (assq prio org-modern-priority-faces))
-                          (cdr (assq t org-modern-priority-faces)))))
+       (if-let* ((face (or (cdr (assq prio org-modern-priority-faces))
+                           (cdr (assq t org-modern-priority-faces)))))
            `(,face org-modern-label)
          'org-modern-priority)))))
 
@@ -466,9 +465,9 @@ the font.")
                                (string (char-before cbeg) ?\s))
             (put-text-property
              colon-end cbeg 'face
-             (if-let ((faces org-modern-tag-faces)
-                      (face (or (cdr (assoc (buffer-substring-no-properties colon-end cbeg) faces))
-                                (cdr (assq t faces)))))
+             (if-let* ((faces org-modern-tag-faces)
+                       (face (or (cdr (assoc (buffer-substring-no-properties colon-end cbeg) faces))
+                                 (cdr (assq t faces)))))
                  `(,face org-modern-tag)
                'org-modern-tag)))
           (add-text-properties cbeg cend colon-props)
@@ -484,8 +483,8 @@ the font.")
     (put-text-property (1- end) end 'display (string (char-before end) ?\s))
     (put-text-property
      beg end 'face
-     (if-let ((face (or (cdr (assoc todo org-modern-todo-faces))
-                        (cdr (assq t org-modern-todo-faces)))))
+     (if-let* ((face (or (cdr (assoc todo org-modern-todo-faces))
+                         (cdr (assq t org-modern-todo-faces)))))
          `(,face org-modern-label)
        (if (string-match-p org-not-done-regexp todo)
            'org-modern-todo 'org-modern-done)))))
@@ -663,8 +662,8 @@ whole buffer; otherwise, for the line at point."
 
 (defun org-modern--pre-redisplay (_)
   "Compute font parameters before redisplay."
-  (when-let ((box (and org-modern-label-border
-                       (face-attribute 'org-modern-label :box nil t))))
+  (when-let* ((box (and org-modern-label-border
+                        (face-attribute 'org-modern-label :box nil t))))
     (unless (equal (and (listp box) (plist-get box :color))
                    (face-attribute 'default :background nil t))
       (org-modern--update-faces)))
@@ -678,14 +677,14 @@ whole buffer; otherwise, for the line at point."
 
 (defun org-modern--update-faces ()
   "Update border of the `org-modern-label' face."
-  (let* ((border (if (integerp org-modern-label-border)
-                     org-modern-label-border
-                   (max 2 (cond
-                           ((integerp line-spacing)
-                            line-spacing)
-                           ((floatp line-spacing)
-                            (ceiling (* line-spacing (frame-char-height))))
-                           (t (/ (frame-char-height) 10))))))
+  (let* ((border (pcase org-modern-label-border
+                   ((pred integerp)
+                    org-modern-label-border)
+                   ((pred floatp)
+                    (ceiling (* (frame-char-height) org-modern-label-border)))
+                   ((pred functionp)
+                    (funcall org-modern-label-border))
+                   (_ 2)))
          (box (list :color (face-attribute 'default :background nil t)
                     :line-width (cons -1 (- border)))))
     (set-face-attribute 'org-modern-label nil :box box)
@@ -717,11 +716,11 @@ whole buffer; otherwise, for the line at point."
 (defun org-modern--make-font-lock-keywords ()
   "Compute font-lock keywords."
   (append
-   (when-let ((bullet (alist-get ?+ org-modern-list)))
+   (when-let* ((bullet (alist-get ?+ org-modern-list)))
      `(("^[ \t]*\\(+\\)[ \t]" 1 '(face nil display ,bullet))))
-   (when-let ((bullet (alist-get ?- org-modern-list)))
+   (when-let* ((bullet (alist-get ?- org-modern-list)))
      `(("^[ \t]*\\(-\\)[ \t]" 1 '(face nil display ,bullet))))
-   (when-let ((bullet (alist-get ?* org-modern-list)))
+   (when-let* ((bullet (alist-get ?* org-modern-list)))
      `(("^[ \t]+\\(*\\)[ \t]" 1 '(face nil display ,bullet))))
    (when org-modern-priority
      `(("^\\*+.*? \\(\\(\\[\\)#.\\(\\]\\)\\) "
@@ -749,12 +748,12 @@ whole buffer; otherwise, for the line at point."
      '(("^[ \t]*\\(|.*|\\)[ \t]*$" (0 (org-modern--table)))))
    (when org-modern-footnote
      `(("^\\(\\[fn:\\)[[:word:]-_]+\\]" ;; Definition
-        ,@(if-let ((x (car org-modern-footnote)))
+        ,@(if-let* ((x (car org-modern-footnote)))
               `((0 '(face nil display ,x))
                 (1 '(face nil display ,(propertize "[" 'display x))))
             '((1 '(face nil display "[")))))
        ("[^\n]\\(\\(\\[fn:\\)[[:word:]-_]+\\]\\)" ;; Reference
-        ,@(if-let ((x (cdr org-modern-footnote)))
+        ,@(if-let* ((x (cdr org-modern-footnote)))
               `((1 '(face nil display ,x))
                 (2 '(face nil display ,(propertize "[" 'display x))))
             '((2 '(face nil display "[")))))))
@@ -919,10 +918,10 @@ whole buffer; otherwise, for the line at point."
         (when org-modern-todo
           (goto-char (point-min))
           (while (< (point) (point-max))
-            (when-let ((org-not-done-regexp (get-text-property (point) 'org-not-done-regexp))
-                       (re (get-text-property (point) 'org-todo-regexp))
-                       (re (concat "[: ]" re " "))
-                       ((re-search-forward re (pos-eol) 'noerror)))
+            (when-let* ((org-not-done-regexp (get-text-property (point) 'org-not-done-regexp))
+                        (re (get-text-property (point) 'org-todo-regexp))
+                        (re (concat "[: ]" re " "))
+                        ((re-search-forward re (pos-eol) 'noerror)))
               (org-modern--todo))
             (goto-char (min (1+ (pos-eol)) (point-max)))))
         (when org-modern-tag
@@ -934,7 +933,7 @@ whole buffer; otherwise, for the line at point."
           (goto-char (point-min))
           (while (re-search-forward "\\(\\[#.\\]\\)" nil 'noerror)
             ;; For some reason the org-agenda-fontify-priorities adds overlays?!
-            (when-let ((ov (overlays-at (match-beginning 0))))
+            (when-let* ((ov (overlays-at (match-beginning 0))))
               (overlay-put (car ov) 'face nil))
             (org-modern--priority)))))))
 
